@@ -41,9 +41,6 @@ public:
 
     PlayerManager *playerManager() const;
 
-    // Use a null cover for failure
-    void coverDownloaded(const QPixmap &cover);
-
 private:
     void setupLayout();
     void setupActions();
